@@ -136,7 +136,7 @@ void Poller::addTimeout(int nextTimeout)
     m_timeouts.insert(nextTimeout, timeout);
     connect(timeout, &KWayland::Client::IdleTimeout::idle, this,
         [this, nextTimeout] {
-            emit timeoutReached(nextTimeout);
+            Q_EMIT timeoutReached(nextTimeout);
         }
     );
     connect(timeout, &KWayland::Client::IdleTimeout::resumeFromIdle, this, &Poller::resumingFromIdle);
@@ -170,7 +170,7 @@ void Poller::catchIdleEvent()
     connect(m_catchResumeTimeout, &KWayland::Client::IdleTimeout::resumeFromIdle, this,
         [this] {
             stopCatchingIdleEvents();
-            emit resumingFromIdle();
+            Q_EMIT resumingFromIdle();
         }
     );
 }
